{% load i18n %}

<html>

<head>
    <meta charset="utf-8">
    <meta http-equiv="x-ua-compatible" content="ie=edge">
    <title>{% translate "Atonra Research Newsletter" %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <style type="text/css">
        /**
   * Google webfonts. Recommended to include the .woff version for cross-client compatibility.
   */
        @media screen {
            @font-face {
                font-family: 'Source Sans Pro';
                font-style: normal;
                font-weight: 400;
                src: local('Source Sans Pro Regular'), local('SourceSansPro-Regular'), url(https://fonts.gstatic.com/s/sourcesanspro/v10/ODelI1aHBYDBqgeIAH2zlBM0YzuT7MdOe03otPbuUS0.woff) format('woff');
            }

            @font-face {
                font-family: 'Source Sans Pro';
                font-style: normal;
                font-weight: 700;
                src: local('Source Sans Pro Bold'), local('SourceSansPro-Bold'), url(https://fonts.gstatic.com/s/sourcesanspro/v10/toadOcfmlt9b38dHJxOBGFkQc6VGVFSmCnC_l7QZG60.woff) format('woff');
            }
        }

        /**
   * Avoid browser level font resizing.
   * 1. Windows Mobile
   * 2. iOS / OSX
   */
        body,
        table,
        td,
        a {
            -ms-text-size-adjust: 100%;
            /* 1 */
            -webkit-text-size-adjust: 100%;
            /* 2 */
        }
        .ExternalClass {width: 100%;}
        /**
   * Remove extra space added to tables and cells in Outlook.
   */
        table,
        td {
            mso-table-rspace: 0pt;
            mso-table-lspace: 0pt;
        }

        /**
   * Better fluid images in Internet Explorer.
   */
        img {
            -ms-interpolation-mode: bicubic;
        }

        /**
   * Remove blue links for iOS devices.
   */
        a[x-apple-data-detectors] {
            font-family: inherit !important;
            font-size: inherit !important;
            font-weight: inherit !important;
            line-height: inherit !important;
            color: inherit !important;
            text-decoration: none !important;
        }

        /**
   * Fix centering issues in Android 4.4.
   */
        div[style*="margin: 16px 0;"] {
            margin: 0 !important;
        }

        body {
            width: 100% !important;
            height: 100% !important;
            padding: 0 !important;
            margin: 0 !important;
        }

        /**
   * Collapse table borders to avoid space between cells.
   */
        table {
            border-collapse: collapse !important;
        }

        a {
            color: #1a82e2;
        }

        img {
            height: auto;
            line-height: 100%;
            text-decoration: none;
            border: 0;
            outline: none;
        }
    </style>

</head>

<body style="background-color: #eaf2ff;">
    <!-- start body -->
    <table border="0" cellpadding="0" cellspacing="0" width="100%">

        <!-- start logo -->
        <tr>
            <td align="center" bgcolor="#eaf2ff">
                <!--[if (gte mso 9)|(IE)]>
        <table align="center" border="0" cellpadding="0" cellspacing="0" width="800">
        <tr>
        <td align="center" valign="top" width="800">
        <![endif]-->
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="width:800px;max-width:800px;">
                    <tr>
                        <td align="center" valign="top" style="padding-top: 36px;">
                            <img src="https://atonra.fra1.digitaloceanspaces.com/public/atonra_banderol.png" border="0"
                                width="800" alt="{% translate 'Atonrâ Logo' %}" style="display: block; width:800px; max-width:800px;height: auto;">
                        </td>
                    </tr>
                </table>
                <!--[if (gte mso 9)|(IE)]>
        </td>
        </tr>
        </table>
        <![endif]-->
            </td>
        </tr>
        <!-- end logo -->

        <!-- start hero -->
        <tr>
            <td align="center" bgcolor="#eaf2ff">
                <!--[if (gte mso 9)|(IE)]>
                <table align="center" border="0" cellpadding="0" cellspacing="0" width="800">
                <tr>
                <td align="center" valign="top" width="800">
                <![endif]-->
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="max-width:800px;">
                    <tr>
                        <td align="left" bgcolor="#ffffff"
                            style="padding: 26px 24px 0; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif;">
                            <h1
                                style="margin: 0; font-size: 22px; font-weight: 800; letter-spacing: -1px; line-height: 48px;">
                                {{salutation}},
                            </h1>
                            <p>{% blocktranslate %}The monthly factsheets for our various equity portfolios have just been updated. Please find a quick summary below.</p>
 <p>If you want more detailed data or the factsheet as a pdf, please visit our interactive factsheets {% endblocktranslate %}<a href="https://atonra.stainly-bench.com/public/factsheet">{% translate "here" %}</a>.</p>
                        </td>
                    </tr>
                </table>
                <!--[if (gte mso 9)|(IE)]>
        </td>
        </tr>
        </table>
        <![endif]-->
            </td>
        </tr>
        <!-- end hero -->

        <!-- start copy block -->
        <tr>
            <td align="center" bgcolor="#eaf2ff">
                <!--[if (gte mso 9)|(IE)]>
                <table align="center" border="0" cellpadding="0" cellspacing="0" width="800">
                <tr>
                <td align="center" valign="top" width="800">
                <![endif]-->
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="max-width:800px;">

                    <!-- start copy -->
                    <tr>
                        <td align="left" bgcolor="#ffffff"
                            style="padding: 24px; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 16px; line-height: 24px;">
                            <a href="https://atonra.stainly-bench.com/public/factsheet">
                            <img src="{{content|safe}}"
                                border="0" width="752"
                                alt="{% translate 'Factsheet Summary' %}"
                                style="display: block; width:752px; max-width:752px;height: auto;">
                            </a>
                        </td>
                    </tr>
                    <!-- end copy -->

                    <!-- start copy -->
                    <tr>
                        <td align="left" bgcolor="#ffffff"
                            style="padding: 0 24px 24px 24px; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 16px; line-height: 24px; border-bottom: 3px solid #d4dadf">
                            <p style="margin: 0;">{% translate "Best Regards," %}</p>
                            <p style="margin: 0;">{% translate "The AtonRâ Partners Team." %}</p>
                        </td>
                    </tr>
                    <!-- end copy -->

                </table>
                <!--[if (gte mso 9)|(IE)]>
                </td>
                </tr>
                </table>
                <![endif]-->
            </td>
        </tr>
        <!-- end copy block -->

        <!-- start footer -->
        <tr>
            <td align="center" bgcolor="#eaf2ff" style="padding: 24px;">
                <!--[if (gte mso 9)|(IE)]>
                <table align="center" border="0" cellpadding="0" cellspacing="0" width="800">
                <tr>
                <td align="center" valign="top" width="800">
                <![endif]-->
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="max-width:800px;">

                    <!-- start permission -->
                    <tr>
                        <td align="center" bgcolor="#eaf2ff"
                            style="padding: 12px 24px; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 14px; line-height: 20px; color: #666;">
                            <p style="margin: 0;" style="text-align: center">
                                <b>{% blocktranslate %}AtonRâ Partners SA</b><br />
                                7, rue de la Croix d’Or, 1204 Geneva, Switzerland{% endblocktranslate %}<br />
                            </p>
                            <table border="0" cellpadding="0" cellspacing="0" width="100%" style="max-width:800px;">
                                <tr>
                                    <td align="center" bgcolor="#eaf2ff"
                                        style="width:33%; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 14px; line-height: 20px; color: #666;">
                                        🌍: <a href="https://www.atonra.ch" target="_blank">https://www.atonra.ch</a>
                                    </td>
                                    <td align="center" bgcolor="#eaf2ff"
                                        style="width:33%;  font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 14px; line-height: 20px; color: #666;">
                                        @: <a href="mailto:team@atonra.ch">team@atonra.ch</a>
                                    </td>
                                    <td align="center" bgcolor="#eaf2ff"
                                        style="width:33%; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 14px; line-height: 20px; color: #666;">
                                        ☎️: <a href="tel:+41-229-061-616">+41 22 906 16 16</a>
                                    </td>
                                </tr>
                            </table>
                        </td>
                    </tr>
                    <tr>
                        <td align="center" bgcolor="#eaf2ff"
                            style="padding: 12px 24px; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 14px; line-height: 20px; color: #666;">
                            <p style="margin: 0;" style="text-align: center">{% blocktranslate %}<b>About AtonRâ Partners:</b> AtonRâ
                                Partners is an asset management
                                company, founded in
                                2004 with head office in Geneva, incorporated under Swiss law, duly approved by the
                                Swiss Financial
                                Market Supervisory Authority (FINMA) under the Swiss Collective Investment Schemes Act.
                                AtonRâ
                                Partners is a conviction-driven asset manager combining industrial and scientific
                                research with
                                financial analysis. AtonRâ Partners focuses on long-term trends powerful enough to be
                                turned into
                                thematic equity portfolios.{% endblocktranslate %}</p>
                        </td>
                    </tr>
                    <!-- end permission -->

                    <!-- start unsubscribe -->
                    <tr>
                        <td align="center" bgcolor="#eaf2ff"
                            style="padding: 12px 24px; font-family: 'Source Sans Pro', Helvetica, Arial, sans-serif; font-size: 14px; line-height: 20px; color: #666;">
                            {% if unsubscribe %}
                            <p style="margin: 0;" style="text-align: center">{% blocktranslate %}If you receive this email because you are
                                subscribed to our mailing list:
                                Please feel free to {% endblocktranslate %}{{unsubscribe|safe}} </p>
                            {% endif %}
                        </td>
                    </tr>
                    <!-- end unsubscribe -->

                </table>
                <!--[if (gte mso 9)|(IE)]>
                </td>
                </tr>
                </table>
                <![endif]-->
            </td>
        </tr>
        <!-- end footer -->

    </table>
    <!-- end body -->

</body>

</html>
